@@ -415,7 +415,7 @@ class HomeMan:
             os.removedirs(usr_path)
         logger.info('restore: %s', route)
 
-    def check(self, route: str, show_diff: bool):
+    def check(self, route: str, show_diff: bool, formatter: str = 'none'):
         logger.debug('========< check >========')
         data = self.get_data(route)
         if data is None:
@@ -423,11 +423,11 @@ class HomeMan:
             return
         for homeman_data in self.__scan_data(data):
             try:
-                self.__check(homeman_data, show_diff)
+                self.__check(homeman_data, show_diff, formatter)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __check(self, data: Dict[str, str], show_diff: bool):
+    def __check(self, data: Dict[str, str], show_diff: bool, formatter: str = 'none'):
         route = data['homeman']
         usr_path = self.usr_home + route
         usr_path_bak = usr_path + '.homeman.bak'
@@ -472,8 +472,18 @@ class HomeMan:
                                 print('is dir inside')
                             else:
                                 with open(usr_f, 'r') as uf, open(man_f, 'r') as mf:
+                                    if formatter == 'json':
+                                        ulines = json.dumps(
+                                            json.load(uf), indent=2
+                                        ).splitlines(keepends=True)
+                                        mlines = json.dumps(
+                                            json.load(mf), indent=2
+                                        ).splitlines(keepends=True)
+                                    else:
+                                        ulines = uf.readlines()
+                                        mlines = mf.readlines()
                                     res = ['------ start ------\n']
-                                    res.extend(list(differ.compare(uf.readlines(), mf.readlines())))
+                                    res.extend(list(differ.compare(ulines, mlines)))
                                     res.append('------ end ------\n')
                                     common_counter = 0
                                     last_line = '\n'
@@ -606,6 +616,10 @@ def main():
         '-v', '--show', action='store_true',
         help='show diff'
     )
+    command_check.add_argument(
+        '-f', '--formatter', type=str, choices=['none', 'json'], default='none',
+        help='show diff'
+    )
 
     args = homeman_parse.parse_args()
 
@@ -641,7 +655,7 @@ def main():
             elif args.command == 'restore':
                 hm.restore(route)
             elif args.command == 'check':
-                hm.check(route, args.show)
+                hm.check(route, args.show, args.formatter)
     except HomeManException as e:
         logger.error(e)
         return 1
